# Introduction to ggplot2 and the mpg dataset
library(ggplot2)

# Look at the data we're going to use
?mpg
head(mpg)
str(mpg)

# Basic scatterplot
qplot(displ, hwy, data = mpg)

# Add an additional variable with aesthetics: colour, shape, size
qplot(displ, hwy, data = mpg, colour = class)
qplot(displ, hwy, data = mpg, colour = cyl)
qplot(displ, hwy, data = mpg, shape = factor(cyl))
qplot(displ, hwy, data = mpg, shape = factor(cyl), colour = factor(cyl))

# Add an additional variable with faceting
qplot(displ, hwy, data = mpg)
qplot(displ, hwy, data = mpg) + facet_grid(. ~ cyl)
qplot(displ, hwy, data = mpg) + facet_grid(drv ~ .)
qplot(displ, hwy, data = mpg) + facet_grid(drv ~ cyl)
qplot(displ, hwy, data = mpg) + facet_wrap(~ class)

# Deal with overplotting
qplot(cty, hwy, data = mpg)
qplot(cty, hwy, data = mpg, geom = "jitter")
qplot(cty, hwy, data = mpg, geom = "jitter", colour = year)
qplot(cty, hwy, data = mpg, geom = "jitter", colour = class)
qplot(cty, hwy, data = mpg, geom = "jitter", colour = class) +
  geom_smooth(method = "lm")

# Reordering + boxplots
qplot(class, hwy, data = mpg)
qplot(reorder(class, hwy), hwy, data = mpg)
qplot(reorder(class, hwy), hwy, data = mpg, geom = "jitter")
qplot(reorder(class, hwy), hwy, data = mpg, geom = "boxplot")
qplot(reorder(class, hwy), hwy, data = mpg, geom = c("jitter", "boxplot"))

