library(plyr)
bnames <- read.csv("baby-names.csv", stringsAsFactors = FALSE)

library(ggplot2)
qplot(year, prop, colour = sex, 
  data = subset(bnames, name == "Hadley"), 
  geom = "line")
  
# Add variables of interest to dataset
letter <- function(x, n = 1) {
  if (n < 0) {
    nc <- nchar(x)
    n <- nc + n + 1
  }
  tolower(substr(x, n, n))
}
vowels <- function(x) {
  nchar(gsub("[^aeiou]", "", x))
}

bnames <- transform(bnames,
  first = letter(name, 1),
  last = letter(name, -1),
  vowels = vowels(name),
  length = nchar(name)  
)


# Look at names starting with Dian -------------------------------------------
dian <- subset(bnames, substr(name, 1, 4) == "Dian")
qplot(year, prop, data = dian, geom = "line")
qplot(year, prop, data = dian, geom = "line", group = name)
qplot(year, prop, data = dian, geom = "line", group = interaction(name, sex))

qplot(year, prop, data = dian, geom = "line", colour = sex) + 
  facet_wrap(~ name)
last_plot() + geom_point()

# Calculating group-wise ranks -----------------------------------------------

## Do it for one piece
one <- subset(bnames, sex == "boy" & year == 2008)
one$rank <- rank(-one$prop, 
  ties.method = "first")

# or
one <- transform(one, 
  rank = rank(-prop, ties.method = "first"))
head(one)

## Do it for many pieces with split and a for loop
# Split
pieces <- split(bnames, 
  list(bnames$sex, bnames$year))

# Apply
results <- vector("list", length(pieces))
for(i in seq_along(pieces)) {
  piece <- pieces[[i]]
  piece <- transform(piece, 
    rank = rank(-prop, ties.method = "first"))
  results[[i]] <- piece
}

# Combine
result <- do.call("rbind", results)

## Do it with ddply
bnames <- ddply(bnames, c("sex", "year"), transform, 
  rank = rank(-prop, ties.method = "first"))  


# Explore length of names over time ------------------------------------------

# Explore average length

wtd.mean <- function(x, weights) 
  sum(weights * x) / sum(weights)

sy <- ddply(bnames, c("sex", "year"), summarise, 
  avg_length = wtd.mean(length, prop))

qplot(year, avg_length, data = sy, colour = sex, 
  geom = "line")
  
# Explore number of names of each length

syl <- ddply(bnames, c("sex", "length", "year"), 
  summarise, prop = sum(prop))
qplot(year, prop, data = syl, colour = sex, 
  geom = "line") + facet_wrap(~ length)

twoletters <- subset(bnames, length == 2)
unique(twoletters$name)
qplot(year, prop, data = twoletters, colour = sex, 
  geom = "line") + facet_wrap(~ name)
  
# The proportion of names in the top 1000 ------------------------------------

sy <- ddply(bnames, c("year","sex"), summarise, 
  prop = sum(prop), 
  npop = sum(prop > 1/1000))

qplot(year, prop, data = sy, colour = sex, geom = "line")
qplot(year, npop, data = sy, colour = sex, geom = "line")

# Distribution of last letters -----------------------------------------------

syl <- ddply(bnames, c("sex", "last", "year"), summarise, 
  prop = sum(prop))
qplot(year, prop, data = syl, colour = sex, geom = "line") + 
  facet_wrap(~ last)
